(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[      7154,        225]
NotebookOptionsPosition[      6160,        189]
NotebookOutlinePosition[      6640,        208]
CellTagsIndexPosition[      6597,        205]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["Load the LGSBloch package", "Text"],

Cell[BoxData[
 RowBox[{"SetDirectory", "[", 
  RowBox[{"NotebookDirectory", "[", "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"<<", "LGSBloch`"}]], "Input"],

Cell["\<\
Generate the system of equations for the Na D2 line. (This can take a few \
minutes.)\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"NaD2LGS", "=", 
   RowBox[{"GenerateLGSSystem", "[", "]"}]}], ";"}]], "Input"],

Cell["\<\
 If you like, you can save the generated data to a file, so that you can \
recall it in the next Mathematica session with \
Get[ToFileName[NotebookDirectory[],\[CloseCurlyDoubleQuote]NaD2LGS.mx\
\[CloseCurlyDoubleQuote]]], without having to compute it again.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"Save", "[", 
  RowBox[{
   RowBox[{"ToFileName", "[", 
    RowBox[{
     RowBox[{"NotebookDirectory", "[", "]"}], ",", "\"\<NaD2LGS.mx\>\""}], 
    "]"}], ",", "NaD2LGS"}], "]"}]], "Input"],

Cell[TextData[{
 "Run a test calculation of return flux (in ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{"photons", "/", 
      StyleBox["s",
       FontSlant->"Plain"]}], "/", "sr"}], "/", 
    RowBox[{"(", 
     RowBox[{
      StyleBox["W",
       FontSlant->"Plain"], "/", 
      SuperscriptBox[
       StyleBox["m",
        FontSlant->"Plain"], "2"]}]}]}], TraditionalForm]]],
 ") emitted in the mesosphere) for a cw laser. Result should be ",
 "258.757",
 " if everything is working properly."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PsiMeso", "[", 
  RowBox[{"NaD2LGS", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"IMeso", "\[Rule]", "46.0"}], ",", 
     RowBox[{"RepumpFraction", "\[Rule]", "0.12"}], ",", 
     RowBox[{"BG", "\[Rule]", "BGParanal"}]}], "}"}]}], "]"}]], "Input"],

Cell[BoxData["258.756657744903`"], "Output"]
}, Open  ]],

Cell["Here are the default parameters for PsiMeso.", "Text"],

Cell[CellGroupData[{

Cell[BoxData["$DefaultLGSParameters"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"IMeso", "\[Rule]", "46.`"}], ",", 
   RowBox[{"RepumpFraction", "\[Rule]", "0.12`"}], ",", 
   RowBox[{"LightPolarization", "\[Rule]", "1.`"}], ",", 
   RowBox[{"LightWavelength", "\[Rule]", "5.89159`*^-7"}], ",", 
   RowBox[{"Phase", "\[Rule]", "0.`"}], ",", 
   RowBox[{"FWHMbw", "\[Rule]", "0.`"}], ",", 
   RowBox[{"\[CapitalDelta]fLaser", "\[Rule]", "0.`"}], ",", 
   RowBox[{"\[CapitalDelta]fLaserDabOff", "\[Rule]", "0.`"}], ",", 
   RowBox[{"LaserWidth", "\[Rule]", "0"}], ",", 
   RowBox[{"BG", "\[Rule]", "0.2275`"}], ",", 
   RowBox[{"Ta", "\[Rule]", "0.84`"}], ",", 
   RowBox[{"Temperature", "\[Rule]", "185.`"}], ",", 
   RowBox[{"SDampingTime", "\[Rule]", "0.000245`"}], ",", 
   RowBox[{"VccTime", "\[Rule]", "0.000035`"}], ",", 
   RowBox[{"HNa", "\[Rule]", "92000.`"}], ",", 
   RowBox[{"vrms\[Gamma]", "\[Rule]", "38.`"}], ",", 
   RowBox[{"RecoilShift", "\[Rule]", "314159.2653589793`"}], ",", 
   RowBox[{"VccRateFunction", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"PLaunch", "\[Rule]", "20.`"}], ",", 
   RowBox[{"Zenith", "\[Rule]", "0.5235987755982989`"}], ",", 
   RowBox[{"Htele", "\[Rule]", "2650.`"}], ",", 
   RowBox[{"DLT", "\[Rule]", "0.4`"}], ",", 
   RowBox[{"\[Mu]LT", "\[Rule]", "1.3888888888888888`"}], ",", 
   RowBox[{"MsqrLT", "\[Rule]", "1.1`"}], ",", 
   RowBox[{"MagneticZenith", "\[Rule]", "1.5707963267948966`"}], ",", 
   RowBox[{"MagneticAzimuth", "\[Rule]", "1.5707963267948966`"}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Atmospheric and Mesospheric Parameters:\n\tBG: Mesospheric geomagnetic \
field strength ",
 Cell[BoxData[
  FormBox[
   RowBox[{"[", 
    StyleBox["G",
     FontSlant->"Plain"], "]"}], TraditionalForm]]],
 "\n\tTa: One-way transmission at \[Lambda] at zenith\n\tTemperature: \
Mesospheric temperature [K]\n\ttauCollMult: Multiplier for S- and v-damping \
collision times\n\tHNa: Altitude of sodium centroid above sea level [m]\n\t\
vrms\[Gamma]: rms velocity of diffusion effects [m/s], \[Gamma] = \
vrms\[Gamma] / (DLT/\[Mu]LT)"
}], "Text"],

Cell[TextData[{
 "Launch Telescope System (LTS) Parameters:\n\tPLaunch: Launched power [W]\n\t\
",
 "Zenith",
 ": Zenith angle [rad]\n\tHtele: Altitude of launch telescope above sea level \
[m]\n\tDLT: Launch telescope aperture [m]\n\t\[Mu]LT: Ratio of DLT to ",
 Cell[BoxData[
  FormBox[
   RowBox[{"1", "/", 
    SuperscriptBox["e", "2"]}], TraditionalForm]]],
 " lauch beam intensity diameter (not radius!), see Yura, Eq.(2.7)\n\tMsqrLT: \
",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["M", "2"], TraditionalForm]]],
 " beam quality factor out of the launch telescope\n\tMagneticZenith, \
MagneticAzimuth: elevation and azimuth angles of B vector in a system where \
the laser points along z "
}], "Text"],

Cell[TextData[{
 "Numerical Parameters:\n\tIMesoMax: Maximum intensity in mesosphere. If set \
to zero, the routine determines it automatically  ",
 Cell[BoxData[
  FormBox[
   RowBox[{"[", 
    RowBox[{
     StyleBox["W",
      FontSlant->"Plain"], "/", 
     SuperscriptBox[
      StyleBox["m",
       FontSlant->"Plain"], "2"]}], "]"}], TraditionalForm]]],
 "\n\tIMesoInitial: Starting mesospheric laser intensity  ",
 Cell[BoxData[
  FormBox[
   RowBox[{"[", 
    RowBox[{
     StyleBox["W",
      FontSlant->"Plain"], "/", 
     SuperscriptBox[
      StyleBox["m",
       FontSlant->"Plain"], "2"]}], "]"}], TraditionalForm]]],
 "\n\tMaxStepRatio: controls intensity step size\n\tIMesoFactor: multiply \
peak intensity by this factor to compute maximum repository intensity\n\t\
NSamples: number of samples in repository"
}], "Text"]
},
WindowSize->{720, 852},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> True}},
ShowSelection->True,
TrackCellChangeTimes->False,
FrontEndVersion->"10.4 for Mac OS X x86 (32-bit, 64-bit Kernel) (April 11, \
2016)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 41, 0, 26, "Text"],
Cell[601, 22, 104, 2, 29, "Input"],
Cell[708, 26, 53, 1, 28, "Input"],
Cell[764, 29, 109, 3, 26, "Text"],
Cell[876, 34, 113, 3, 29, "Input"],
Cell[992, 39, 282, 5, 41, "Text"],
Cell[1277, 46, 213, 6, 29, "Input"],
Cell[1493, 54, 532, 19, 47, "Text"],
Cell[CellGroupData[{
Cell[2050, 77, 276, 7, 29, "Input"],
Cell[2329, 86, 44, 0, 28, "Output"]
}, Open  ]],
Cell[2388, 89, 60, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[2473, 93, 47, 0, 28, "Input"],
Cell[2523, 95, 1506, 29, 133, "Output"]
}, Open  ]],
Cell[4044, 127, 559, 13, 116, "Text"],
Cell[4606, 142, 709, 18, 140, "Text"],
Cell[5318, 162, 838, 25, 113, "Text"]
}
]
*)

